@@ -1,6 +1,6 @@
 import flask
 import flask.signals
-from flask import _app_ctx_stack as stack
+from flask import current_app
 import functools
 import logging
 import requests
@@ -13,7 +13,7 @@ try:
 except ImportError:  # pragma: no cover
     import urlparse
 
-__version__ = '0.4.4'
+__version__ = '0.5.0'
 
 log = logging.getLogger(__name__)
 
@@ -137,7 +137,7 @@ class FlaskSAML(object):
 
 
 def _get_return_to():
-    ext, config = stack.top.app.extensions['saml']
+    ext, config = current_app.extensions['saml']
     return_to = flask.request.args.get('next', '')
     if not return_to.startswith(flask.request.url_root):
         return_to = config['default_redirect']
@@ -150,7 +150,7 @@ def logout(saml_client):
     saml_log_out.send(
         flask.current_app._get_current_object(),
     )
-    ext, config = stack.top.app.extensions['saml']
+    ext, config = current_app.extensions['saml']
     url = flask.request.url_root[:-1] + config['default_redirect']
     return flask.redirect(url)
 
@@ -195,7 +195,7 @@ def login_acs(saml_client):
                 auth=authn_response,
             )
         relay_state = flask.request.form.get('RelayState')
-        ext, config = stack.top.app.extensions['saml']
+        ext, config = current_app.extensions['saml']
         if not relay_state:
             relay_state = config['default_redirect']
         redirect_to = relay_state
